#include "Serveur.h"

Serveur::Serveur(uint16_t port/*=80*/) : WiFiServer(port)
{
  ledPin2 = 02; // Led bleue  
  pinMode(ledPin2, OUTPUT);
  etatLed = LOW;
  digitalWrite(ledPin2, etatLed);
}

void Serveur::demarrer()
{
  demarrerWiFi();
  demarrerServeur();
}

void Serveur::traiterRequete()
{
  WiFiClient client = available();
  if (!client) 
  {
    return;
  }
  
  Serial.print("Requête client ");
  while(!client.available())
  {
    delay(1);
  }
  Serial.println(client.remoteIP());  
  
  //String requete = client.readStringUntil('\r');  
  //Serial.println(requete);
  //client.flush();

  String requete;
  while(client.available())
  {
    String ligne = client.readStringUntil('\r');
    Serial.print(ligne);
    requete += ligne;
  }
  client.flush();

  if(requete.indexOf("GET") != -1)
  {
    envoyerPageAccueil(client);    
  }
  else if(requete.indexOf("POST") != -1)
  {
      if(requete.indexOf("led") != -1)
      {          
        if(requete.indexOf("led=0") != -1)
        {
          etatLed = HIGH;
          digitalWrite(ledPin2, etatLed);  
        }
        else if(requete.indexOf("led=1") != -1)
        {
          etatLed = LOW;
          digitalWrite(ledPin2, etatLed);
        }
        envoyerPageAccueil(client);    
      }
  }
  else 
  {
    Serial.println("Requête invalide !");
    client.stop();
    return;
  }
  
  Serial.println("");
}

void Serveur::demarrerWiFi()
{
  Serial.println("");
  Serial.println("");
  Serial.print("Connexion au réseau WiFi ");
  Serial.println(ssid);
  
  WiFi.mode(WIFI_STA);
  WiFi.begin(ssid, password);
  
  while (WiFi.status() != WL_CONNECTED) 
  {
    delay(500);
    Serial.print(".");
  }
  Serial.println("");
  Serial.print("Adresse IP du serveur : ");
  Serial.println(WiFi.localIP());  
}

void Serveur::demarrerServeur()
{  
  begin();
  Serial.println("Démarrage du serveur Web");
  Serial.println("");
}

void Serveur::envoyerPageAccueil(WiFiClient &client)
{  
  String reponse = "HTTP/1.1 200 OK\r\nContent-Type: text/html\r\nPragma: no-cache\r\n\r\n<!DOCTYPE HTML>\r\n";
  reponse += "<html>\n";
  reponse += "<head>\n";
  reponse += "<title>Serveur ESP8266</title>\n";
  reponse += "</head>\n";
  reponse += "<body>\n";
  reponse += "<h1>Bienvenue sur le serveur ESP8266 WiFi !</h1>\n";
  reponse += "<p>\n";
  reponse += "<form method=\"POST\">\n";  
  if (etatLed == LOW) 
  {
    reponse += "<p><input type=\"radio\" id=\"led\" name=\"led\" value=\"0\" />LED off\n";
    reponse += "<br /><input type=\"radio\" id=\"led\" name=\"led\" value=\"1\" checked />LED on</p>";
    
  } 
  else 
  {
    reponse += "<p><input type=\"radio\" id=\"led\" name=\"led\" value=\"0\" checked>LED off</input>\n";
    reponse += "<br /><input type=\"radio\" id=\"led\" name=\"led\" value=\"1\">LED on</input></p>";
  }
  reponse += "<p><input type=\"submit\" /></p>\n";
  reponse += "</form>\n";
  reponse += "</p>\n";
  reponse += "</body>\n";
  reponse += "</html>\n";

  client.flush();
  client.print(reponse);
  //delay(1);  
}

